@@ -153,11 +153,13 @@ class BestellungsAdmin(admin.ModelAdmin):
                 ('Einstellungen', {'fields': [
                  'zahlungsempfaenger', 'ansprechpartner']}),
                 ('Infos', {'fields': ['name', 'datum', 'status']}),
+                ('Rechnungsoptionen', {'fields': [
+                 'rechnungstitel', 'rechnungstext', 'rechnungsdatum', 'zahlungskonditionen']}),
                 ('Lieferung', {'fields': ['versendet', 'trackingnummer']}),
                 ('Bezahlung', {'fields': [
                  'bezahlt', 'zahlungsmethode', 'summe', 'summe_mwst', 'summe_gesamt']}),
                 ('Kunde', {'fields': ['kunde']}),
-                ('Notizen', {'fields': ['kundennotiz', 'html_notiz'], 'classes': [
+                ('Notizen & Texte', {'fields': ['kundennotiz', 'html_notiz'], 'classes': [
                  "collapse start-open"]}),
                 ('Rechnungsadresse', {'fields': ['rechnungsadresse_vorname', 'rechnungsadresse_nachname', 'rechnungsadresse_firma', 'rechnungsadresse_adresszeile1', 'rechnungsadresse_adresszeile2',
                                                  'rechnungsadresse_plz', 'rechnungsadresse_ort', 'rechnungsadresse_kanton', 'rechnungsadresse_land', 'rechnungsadresse_email', 'rechnungsadresse_telefon'], 'classes': ["collapse default-open"]}),
@@ -168,12 +170,14 @@ class BestellungsAdmin(admin.ModelAdmin):
             return [
                 ('Einstellungen', {'fields': [
                  'zahlungsempfaenger', 'ansprechpartner']}),
+                ('Rechnungsoptionen', {'fields': [
+                 'rechnungstitel', 'rechnungstext', 'rechnungsdatum', 'zahlungskonditionen']}),
                 ('Lieferung', {'fields': ['trackingnummer'], 'classes': [
                  "collapse"]}),
                 ('Bezahlung', {'fields': ['zahlungsmethode'], 'classes': [
                  "collapse start-open"]}),
                 ('Kunde', {'fields': ['kunde']}),
-                ('Notizen', {'fields': ['kundennotiz'],
+                ('Notizen & Texte', {'fields': ['kundennotiz'],
                              'classes': ["collapse start-open"]}),
             ]
 
@@ -188,7 +192,7 @@ class BestellungsAdmin(admin.ModelAdmin):
             if obj.versendet:
                 fields += ['versendet', 'trackingnummer'] + lieferadresse
             if obj.bezahlt:
-                fields += ['bezahlt', 'zahlungsmethode'] + rechnungsadresse
+                fields += ['bezahlt', 'zahlungsmethode', 'rechnungsdatum'] + rechnungsadresse
             if obj.woocommerceid:
                 fields += ["kundennotiz"]
         return fields
@@ -417,18 +421,18 @@ class LieferungInlineProdukteAdd(admin.TabularInline):
 @admin.register(Lieferung)
 class LieferungenAdmin(admin.ModelAdmin):
     list_display = ('name', 'datum', 'anzahlprodukte',
-                    'eingelagert', 'html_notiz')
-    list_filter = ("eingelagert",)
+                    'lieferant', 'eingelagert', 'html_notiz')
+    list_filter = ("eingelagert", "lieferant", )
 
-    search_fields = ["name", "datum", "notiz__name", "notiz__beschrieb"]
+    search_fields = ["name", "datum", "lieferant", "notiz__name", "notiz__beschrieb"]
 
     readonly_fields = ["html_notiz"]
 
-    ordering = ('name',)
+    ordering = ('-datum',)
 
     fieldsets = [
         ('Infos', {'fields': ['name', 'html_notiz']}),
-        ('Lieferant', {'fields': ['lieferant'], 'classes': ['collapse']})
+        ('Lieferant', {'fields': ['lieferant']})
     ]
 
     inlines = [LieferungInlineProdukte, LieferungInlineProdukteAdd]
