@@ -7,6 +7,7 @@ from django.core.validators import RegexValidator, MinValueValidator, MaxValueVa
 from django.http import FileResponse
 from django.template.loader import get_template
 from django.utils.html import mark_safe
+from django.utils.safestring import mark_safe
 from django.urls import reverse
 
 from datetime import datetime
@@ -15,7 +16,7 @@ from pytz import utc
 from django.utils import timezone
 
 from kmuhelper.utils import send_mail, runden, clean, formatprice, modulo10rekursiv, send_pdf
-from kmuhelper.pdf_generators.bestellung import pdf_bestellung
+from kmuhelper.pdf_generators import PDFOrder
 
 from kmuhelper.emails.models import EMail, EMailAttachment
 
@@ -214,6 +215,16 @@ class Bestellung(models.Model):
 
     datum = models.DateTimeField("Datum", default=timezone.now)
 
+    rechnungsdatum = models.DateField(
+        "Rechnungsdatum", default=None, blank=True, null=True, help_text="Datum der Rechnung. Wird auch als Startpunkt für die Zahlungskonditionen verwendet.")
+    rechnungstitel = models.CharField(
+        "Rechnungstitel", default="", blank=True, max_length=32, help_text="Titel der Rechnung. Leer lassen für 'RECHNUNG'")
+    rechnungstext = models.TextField(
+        "Rechnungstext", default="", blank=True, help_text=mark_safe("Wird auf der Rechnung gedruckt! Unterstützt <abbr title='<b>Fett</b><u>Unterstrichen</u><i>Kursiv</i>'>XML markup</abbr>."))
+    zahlungskonditionen = models.CharField(
+        "Zahlungskonditionen", default="0:30", validators=[RegexValidator("^[0-9]+:[0-9]+(;[0-9]+:[0-9]+)*$")], max_length=16, help_text="Skonto und Zahlfrist nach Syntaxdefinition von Swico. z.B. '2:15;0:30'"
+    )
+
     status = models.CharField("Status", max_length=11,
                               default="pending", choices=STATUS)
     versendet = models.BooleanField(
@@ -230,7 +241,6 @@ class Bestellung(models.Model):
 
     kundennotiz = models.TextField(
         "Kundennotiz", default="", blank=True, help_text="Vom Kunden erfasste Notiz.")
-    #rechnungsnotiz = models.TextField("Rechnungsnotiz", default="", blank=True, help_text="Wird auf der Rechnung gedruckt.")
 
     order_key = models.CharField(
         "Bestellungs-Schlüssel", max_length=50, default=defaultorderkey, blank=True)
@@ -305,28 +315,30 @@ class Bestellung(models.Model):
         if self.pk:
             self.fix_summe = self.summe_gesamt()
             double_save = False
-        elif (not self.woocommerceid) and self.kunde:
-            self.rechnungsadresse_vorname = self.kunde.rechnungsadresse_vorname
-            self.rechnungsadresse_nachname = self.kunde.rechnungsadresse_nachname
-            self.rechnungsadresse_firma = self.kunde.rechnungsadresse_firma
-            self.rechnungsadresse_adresszeile1 = self.kunde.rechnungsadresse_adresszeile1
-            self.rechnungsadresse_adresszeile2 = self.kunde.rechnungsadresse_adresszeile2
-            self.rechnungsadresse_ort = self.kunde.rechnungsadresse_ort
-            self.rechnungsadresse_kanton = self.kunde.rechnungsadresse_kanton
-            self.rechnungsadresse_plz = self.kunde.rechnungsadresse_plz
-            self.rechnungsadresse_land = self.kunde.rechnungsadresse_land
-            self.rechnungsadresse_email = self.kunde.rechnungsadresse_email
-            self.rechnungsadresse_telefon = self.kunde.rechnungsadresse_telefon
+        else:
+            if (not self.woocommerceid) and self.kunde:
+                self.rechnungsadresse_vorname = self.kunde.rechnungsadresse_vorname
+                self.rechnungsadresse_nachname = self.kunde.rechnungsadresse_nachname
+                self.rechnungsadresse_firma = self.kunde.rechnungsadresse_firma
+                self.rechnungsadresse_adresszeile1 = self.kunde.rechnungsadresse_adresszeile1
+                self.rechnungsadresse_adresszeile2 = self.kunde.rechnungsadresse_adresszeile2
+                self.rechnungsadresse_ort = self.kunde.rechnungsadresse_ort
+                self.rechnungsadresse_kanton = self.kunde.rechnungsadresse_kanton
+                self.rechnungsadresse_plz = self.kunde.rechnungsadresse_plz
+                self.rechnungsadresse_land = self.kunde.rechnungsadresse_land
+                self.rechnungsadresse_email = self.kunde.rechnungsadresse_email
+                self.rechnungsadresse_telefon = self.kunde.rechnungsadresse_telefon
 
-            self.lieferadresse_vorname = self.kunde.lieferadresse_vorname
-            self.lieferadresse_nachname = self.kunde.lieferadresse_nachname
-            self.lieferadresse_firma = self.kunde.lieferadresse_firma
-            self.lieferadresse_adresszeile1 = self.kunde.lieferadresse_adresszeile1
-            self.lieferadresse_adresszeile2 = self.kunde.lieferadresse_adresszeile2
-            self.lieferadresse_ort = self.kunde.lieferadresse_ort
-            self.lieferadresse_kanton = self.kunde.lieferadresse_kanton
-            self.lieferadresse_plz = self.kunde.lieferadresse_plz
-            self.lieferadresse_land = self.kunde.lieferadresse_land
+                self.lieferadresse_vorname = self.kunde.lieferadresse_vorname
+                self.lieferadresse_nachname = self.kunde.lieferadresse_nachname
+                self.lieferadresse_firma = self.kunde.lieferadresse_firma
+                self.lieferadresse_adresszeile1 = self.kunde.lieferadresse_adresszeile1
+                self.lieferadresse_adresszeile2 = self.kunde.lieferadresse_adresszeile2
+                self.lieferadresse_ort = self.kunde.lieferadresse_ort
+                self.lieferadresse_kanton = self.kunde.lieferadresse_kanton
+                self.lieferadresse_plz = self.kunde.lieferadresse_plz
+                self.lieferadresse_land = self.kunde.lieferadresse_land
+            self.rechnungsdatum = timezone.now()
         if self.versendet and (not self.ausgelagert):
             for i in self.produkte.through.objects.filter(bestellung=self):
                 i.produkt.lagerbestand -= i.menge
@@ -348,12 +360,13 @@ class Bestellung(models.Model):
         return c
 
     def rechnungsinformationen(self):
-        date = self.datum.strftime("%y%m%d")
+        date = (self.rechnungsdatum or self.datum).strftime("%y%m%d")
         uid = self.zahlungsempfaenger.firmenuid.split("-")[1].replace(".", "")
+        kond = self.zahlungskonditionen
         mwstdict = self.mwstdict()
         mwststring = ";".join(
             satz+":"+str(mwstdict[satz]) for satz in mwstdict)
-        return "//S1/10/"+str(self.pk)+"/11/"+date+"/30/"+uid+"/31/"+date+"/32/"+mwststring+"/40/"+"0:30"
+        return "//S1/10/"+str(self.pk)+"/11/"+date+"/30/"+uid+"/31/"+date+"/32/"+mwststring+"/40/"+kond
 
     def mwstdict(self):
         mwst = {}
@@ -404,7 +417,7 @@ class Bestellung(models.Model):
     __str__.short_description = "Bestellung"
 
     def get_pdf(self, lieferschein: bool = False, digital: bool = True):
-        return FileResponse(pdf_bestellung(self, lieferschein=lieferschein, digital=digital), as_attachment=False, filename=('Lieferschein' if lieferschein else 'Rechnung')+' zu Bestellung '+str(self)+'.pdf')
+        return PDFOrder(self, lieferschein=lieferschein, digital=digital).get_response(as_attachment=False, filename=('Lieferschein' if lieferschein else 'Rechnung')+' zu Bestellung '+str(self)+'.pdf')
 
     def send_pdf_rechnung_to_customer(self):
         context = {
@@ -434,7 +447,7 @@ class Bestellung(models.Model):
             attachments=[
                 EMailAttachment(
                     filename=f"Rechnung Nr. { self.id }"+(" (Online #"+str(self.woocommerceid)+")" if self.woocommerceid else "")+".pdf",
-                    content=pdf_bestellung(self, lieferschein=False, digital=True),
+                    content=PDFOrder(self, lieferschein=False, digital=True).get_pdf(),
                     url=self.get_public_pdf_url(),
                 )
             ],
@@ -892,10 +905,7 @@ class Lieferung(models.Model):
     eingelagert = models.BooleanField("Eingelagert", default=False)
 
     def anzahlprodukte(self):
-        anzahl = 0
-        for i in self.produkte.through.objects.filter(lieferung=self):
-            anzahl += i.menge
-        return anzahl
+        return self.produkte.through.objects.filter(lieferung=self).aggregate(models.Sum('menge'))["menge__sum"]
     anzahlprodukte.short_description = "Produkte"
 
     def einlagern(self):
